---
title: Swiss Systems Engineering Day 2021
---


If you have any questions please contact us at <info@sltoo.dev> or leave a
comment at the end of this site.

# Presentation

The slides are available [here](../../../assets/rmtoo-Traceability.pdf)

## Video

~~will be updated soon~~

Unfortunately there are no video recordings available.

# Reference Implementation

The reference implementation from which the slides draws its screen 
shots: <https://kown7.github.io/pymergevcd/>

The generated documents are the
[architecture specification](https://kown7.github.io/pymergevcd/#architecture)
and 
[requirement specification](https://kown7.github.io/pymergevcd/#requirements).


The reference implementation with github actions and tox for 
running the tests, see the files in the [repository](https://github.com/kown7/pymergevcd):

* Test runner [tox.ini](https://github.com/kown7/pymergevcd/blob/master/tox.ini): `tox -e reqs`
    * Adapt the resource if you're using a different version of python
* CI configuration [github actions](https://github.com/kown7/pymergevcd/blob/master/.github/workflows/main.yml)
* The sources for the documents
    * [Requirements specification](https://github.com/kown7/pymergevcd/tree/master/docs/arch)
    * [Architecture specification](https://github.com/kown7/pymergevcd/tree/master/docs/requirements)


